@@ -12,7 +12,7 @@ from web3 import Web3, HTTPProvider
 from web3.types import RPCEndpoint, RPCResponse, TxParams
 from enum import Enum
 
-from eulith_web3.erc20 import EulithERC20, TokenSymbol
+from eulith_web3.erc20 import EulithERC20, TokenSymbol, EulithWETH
 
 
 class EulithAuthException(Exception):
@@ -275,10 +275,13 @@ class EulithWeb3(Web3):
             if not self.eulith_data.atomic:
                 self.eth.wait_for_transaction_receipt(tx_hash)
 
-    def eulith_get_erc_token(self, symbol: TokenSymbol) -> EulithERC20:
+    def eulith_get_erc_token(self, symbol: TokenSymbol) -> Union[EulithERC20, EulithWETH]:
         status, contract_address_or_error = self.eulith_data.lookup_token_symbol(symbol)
         if status:
-            return EulithERC20(self, contract_address_or_error)
+            if symbol == TokenSymbol.WETH:
+                return EulithWETH(self, contract_address_or_error)
+            else :
+                return EulithERC20(self, contract_address_or_error)
         else:
             raise EulithRpcException(contract_address_or_error)
 
